Introduction
============

Before we dive into the really fun parts -- playbooks, configuration management, deployment, and orchestration -- we'll learn how to get Ansible installed and cover some basic concepts.  We'll also go over how to execute ad-hoc commands in parallel across your nodes using /usr/bin/ansible, and see what sort of modules are available in Ansible's core (you can also write your own, which is covered later).

.. toctree::
   :maxdepth: 1

   intro_installation
   intro_getting_started
   intro_inventory
   intro_dynamic_inventory
   intro_patterns
   intro_adhoc
   intro_configuration
   intro_bsd
   intro_windows
   intro_networking

